NetworkSpeedPlusMethodChannel class

Method channel implementation

Implemented types

Properties

eventChannel EventChannel
Get the event channel for streaming speed data
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
Get the method channel for method calls
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedStream Stream<SpeedData>
Stream of speed data
no setteroverride

Methods

dispose() → void
Dispose resources
override
getMonitoringMode() Future<String>
Get current monitoring mode
override
getUpdateInterval() Future<int>
Get current update interval
override
isMonitoring() Future<bool>
Check if monitoring is active
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUpdateInterval(int seconds) Future<void>
Set update interval
override
startMonitoring({bool monitorTotalTraffic = true, int updateIntervalSeconds = 3}) Future<void>
Start monitoring network speed
override
stopMonitoring() Future<void>
Stop monitoring network speed
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited