SpeedData class
Represents network speed data
Constructors
Properties
- downloadSpeed → double
-
Download speed in KB/s
final
- formattedDownload → String
-
Format speed for display
no setter
- formattedUpload → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- monitorType → String
-
Type of monitoring (total or app)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
Timestamp when the data was captured
final
- uploadSpeed → double
-
Upload speed in KB/s
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited